## The *list-folder.ps1* Script

This PowerShell script lists the directory content formatted in columns.

## Parameters
```powershell
list-folder.ps1 [[-SearchPattern] <String>] [<CommonParameters>]

-SearchPattern <String>
    Specifies the search pattern, "*" by default (means anything)
    
    Required?                    false
    Position?                    1
    Default value                *
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

## Example
```powershell
PS> ./list-folder C:\

```

## Notes
Author: Markus Fleschutz | License: CC0

## Related Links
https://github.com/fleschutz/PowerShell

## Source Code
```powershell
<#
.SYNOPSIS
	Lists the folder content 
.DESCRIPTION
	This PowerShell script lists the directory content formatted in columns.
.PARAMETER SearchPattern
	Specifies the search pattern, "*" by default (means anything) 
.EXAMPLE
	PS> ./list-folder C:\
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$SearchPattern = "*")

function ListFolder { param([string]$SearchPattern)
	$Items = get-childItem -path "$SearchPattern"
	foreach ($Item in $Items) {
		$Name = $Item.Name
		if ($Name[0] -eq '.') { continue } # hidden file/dir
		if ($Item.Mode -like "d*") { $Icon = "📂" 
		} elseif ($Name -like "*.iso") { $Icon = "📀"
		} elseif ($Name -like "*.mp3") { $Icon = "🎵"
		} elseif ($Name -like "*.epub") { $Icon = "📓"
		} else { $Icon = "📄" }
		new-object PSObject -Property @{ Name = "$Icon$Name" }
	}
}

try {
	ListFolder $SearchPattern | format-wide -autoSize
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*Generated by convert-ps2md.ps1 using the comment-based help of list-folder.ps1*
