## The *simulate-presence.ps1* Script

This PowerShell script simulates the human presence against burglars.

## Parameters
```powershell
simulate-presence.ps1 [[-IPaddress] <String>] [<CommonParameters>]

-IPaddress <String>
    Specifies the IP address of the Shelly1 device
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

## Example
```powershell
PS> ./simulate-presence 192.168.100.100

```

## Notes
Author: Markus Fleschutz | License: CC0

## Related Links
https://github.com/fleschutz/PowerShell

## Source Code
```powershell
<#
.SYNOPSIS
	Simulates the human presence against burglars
.DESCRIPTION
	This PowerShell script simulates the human presence against burglars.
.PARAMETER IPaddress
	Specifies the IP address of the Shelly1 device
.EXAMPLE
	PS> ./simulate-presence 192.168.100.100
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$IPaddress = "")

try {
	if ($IPaddress -eq "" ) { $IPaddress = read-host "Enter IP address of Shelly1 device" }

	for ([int]$i = 0; $i -lt 1000; $i++) {
		& "$PSScriptRoot/switch-shelly1.ps1" $IPaddress on 0
		start-sleep -s 10
		& "$PSScriptRoot/switch-shelly1.ps1" $IPaddress off 0
		start-sleep -s 60
	}

	"✔️  Done."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*Generated by convert-ps2md.ps1 using the comment-based help of simulate-presence.ps1*
